@@ -1,11 +1,11 @@
 import React from 'react';
 import * as SharedStyle from '../../shared-style';
 
-var STYLE = { borderTop: '1px solid #222222', borderBottom: '1px solid #48494E' };
+var STYLE = { borderTop: '1px solid #222', borderBottom: '1px solid #48494E' };
 var STYLE_TITLE = {
   fontSize: '11px',
   color: SharedStyle.PRIMARY_COLOR.text_alt,
-  padding: '5px 0 8px 15px',
+  padding: '5px 15px 8px 15px',
   backgroundColor: SharedStyle.PRIMARY_COLOR.alt,
   textShadow: '-1px -1px 2px rgba(0, 0, 0, 1)',
   boxShadow: 'inset 0px -3px 19px 0px rgba(0,0,0,0.5)',
@@ -14,7 +14,7 @@ var STYLE_TITLE = {
 var STYLE_CONTENT = {
   fontSize: '11px',
   color: SharedStyle.PRIMARY_COLOR.text_alt,
-  border: '1px solid #222222',
+  border: '1px solid #222',
   padding: '0px',
   backgroundColor: SharedStyle.PRIMARY_COLOR.alt,
   textShadow: '-1px -1px 2px rgba(0, 0, 0, 1)'
@@ -22,6 +22,7 @@ var STYLE_CONTENT = {
 
 export default function Panel(_ref) {
   var name = _ref.name,
+      headComponents = _ref.headComponents,
       children = _ref.children;
 
   return React.createElement(
@@ -30,7 +31,8 @@ export default function Panel(_ref) {
     React.createElement(
       'h3',
       { style: STYLE_TITLE },
-      name
+      name,
+      headComponents
     ),
     React.createElement(
       'div',
