@@ -96,14 +96,12 @@ export function splitLine(layer, lineID, x, y, catalog) {
 
   layer = layer.withMutations(function (layer) {
     var line = layer.getIn(['lines', lineID]);
-
-    var _layer$vertices$get = layer.vertices.get(line.vertices.get(0)),
-        x0 = _layer$vertices$get.x,
-        y0 = _layer$vertices$get.y;
-
-    var _layer$vertices$get2 = layer.vertices.get(line.vertices.get(1)),
-        x1 = _layer$vertices$get2.x,
-        y1 = _layer$vertices$get2.y;
+    var v0 = layer.vertices.get(line.vertices.get(0));
+    var v1 = layer.vertices.get(line.vertices.get(1));
+    var x0 = v0.x,
+        y0 = v0.y;
+    var x1 = v1.x,
+        y1 = v1.y;
 
     var _addLine = addLine(layer, line.type, x0, y0, x, y, catalog, line.properties);
 
@@ -115,12 +113,11 @@ export function splitLine(layer, lineID, x, y, catalog) {
 
 
     var splitPointOffset = Geometry.pointPositionOnLineSegment(x0, y0, x1, y1, x, y);
+    var minVertex = Geometry.minVertex(v0, v1);
 
     line.holes.forEach(function (holeID) {
       var hole = layer.holes.get(holeID);
 
-      var minVertex = Geometry.minVertex({ x: x0, y: y0 }, { x: x1, y: y1 });
-
       var holeOffset = hole.offset;
       if (minVertex.x === x1 && minVertex.y === y1) {
         splitPointOffset = 1 - splitPointOffset;
@@ -227,16 +224,16 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
           v0 = _line$vertices$map$to2[0],
           v1 = _line$vertices$map$to2[1];
 
-      var hasCommonEndpoint = Geometry.samePoints(v0, { x: x0, y: y0 }) || Geometry.samePoints(v0, { x: x1, y: y1 }) || Geometry.samePoints(v1, { x: x0, y: y0 }) || Geometry.samePoints(v1, { x: x1, y: y1 });
+      var hasCommonEndpoint = Geometry.samePoints(v0, points[0]) || Geometry.samePoints(v0, points[1]) || Geometry.samePoints(v1, points[0]) || Geometry.samePoints(v1, points[1]);
 
-      var intersection = Geometry.intersectionFromTwoLineSegment({ x: x0, y: y0 }, { x: x1, y: y1 }, v0, v1);
+      var intersection = Geometry.intersectionFromTwoLineSegment(points[0], points[1], v0, v1);
 
       if (intersection.type === 'colinear') {
         if (!oldHoles) {
           oldHoles = [];
         }
 
-        var orderedVertices = Geometry.orderVertices([{ x: x0, y: y0 }, { x: x1, y: y1 }]);
+        var orderedVertices = Geometry.orderVertices(points);
 
         layer.lines.get(line.id).holes.forEach(function (holeID) {
           var hole = layer.holes.get(holeID);
