@@ -11,6 +11,7 @@ import FormNumberInput from '../style/form-number-input';
 import FormSubmitButton from '../style/form-submit-button';
 import FormSlider from '../style/form-slider';
 import CancelButton from '../style/cancel-button';
+import diff from 'immutablediff';
 
 import {
   MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN, MODE_3D_VIEW, MODE_3D_FIRST_PERSON,
@@ -20,6 +21,14 @@ import {
 } from '../../constants';
 import * as SharedStyle from '../../shared-style';
 
+const VISIBILITY_MODE = {
+  MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN,
+  MODE_3D_VIEW, MODE_3D_FIRST_PERSON,
+  MODE_WAITING_DRAWING_LINE, MODE_DRAWING_LINE, MODE_DRAWING_HOLE, MODE_DRAWING_ITEM,
+  MODE_DRAGGING_LINE, MODE_DRAGGING_VERTEX, MODE_DRAGGING_ITEM, MODE_DRAGGING_HOLE,
+  MODE_ROTATING_ITEM, MODE_UPLOADING_IMAGE, MODE_FITTING_IMAGE
+};
+
 const styleEditButton = {
   cursor: 'pointer',
   marginLeft: '5px',
@@ -64,6 +73,15 @@ export default class PanelLayers extends Component {
     };
   }
 
+  shouldComponentUpdate(nextProps, nextState) {
+    if( this.props.state.scene.layers.size !== nextProps.state.scene.layers.size ) return true;
+    if( diff( this.props.state.sceneHistory, nextProps.state.sceneHistory ).size ) return true;
+    if( nextState.layerAddUIVisible != this.state.layerAddUIVisible ) return true;
+    if( diff( this.state.editingLayer, nextState.editingLayer ).size ) return true;
+
+    return false;
+  }
+
   addLayer(e) {
     e.stopPropagation();
     if (!this.state.layerAddUIVisible) {
@@ -95,15 +113,9 @@ export default class PanelLayers extends Component {
   }
 
   render() {
+    if (!VISIBILITY_MODE[this.props.state.mode]) return null;
 
-    let {scene, mode} = this.props.state;
-
-    if (![MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN,
-        MODE_3D_VIEW, MODE_3D_FIRST_PERSON,
-        MODE_WAITING_DRAWING_LINE, MODE_DRAWING_LINE, MODE_DRAWING_HOLE, MODE_DRAWING_ITEM,
-        MODE_DRAGGING_LINE, MODE_DRAGGING_VERTEX, MODE_DRAGGING_ITEM, MODE_DRAGGING_HOLE,
-        MODE_ROTATING_ITEM, MODE_UPLOADING_IMAGE, MODE_FITTING_IMAGE].includes(mode)) return null;
-
+    let scene = this.props.state.scene;
     let isLastLayer = scene.layers.size === 1;
 
     return (
